<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns:cbc="urn:oasis:names:specification:ubl:schema:xsd:CommonBasicComponents-2" xmlns:cac="urn:oasis:names:specification:ubl:schema:xsd:CommonAggregateComponents-2" xmlns:ubl="urn:oasis:names:specification:ubl:schema:xsd:Invoice-2" queryBinding="xslt" xmlns="http://purl.oclc.org/dsdl/schematron">
	<!-- 
		Release 1.0c 
		Author: M.P. Diepstra (Innopay) 
		Email: support@simplerinvoicing.org
	-->
	<!-- 
		Usable XPath statements for getting insight into Schematron file:
		//rule[@context=preceding-sibling::rule/@context]      - - - > Gets all rules that might not get fired because they have the same context as previous rules
		max(//assert/substring-before(text(), ']'))   - - - > Gets the maximum number of the current error numbering in the rule set
		//assert[@flag='fatal' or (not(@flag) and parent::rule/@flag='fatal')]    - - - > Gets all asserts that are flagged 'fatal'
		//assert[not(@flag) or @flag != parent::rule/@flag] - - - > Gets all asserts where the flag differs from the rule flag 
	-->
	<title>BIICORE  T10 bound to UBL</title>
	<ns prefix="cbc" uri="urn:oasis:names:specification:ubl:schema:xsd:CommonBasicComponents-2"/>
	<ns prefix="cac" uri="urn:oasis:names:specification:ubl:schema:xsd:CommonAggregateComponents-2"/>
	<ns prefix="ubl" uri="urn:oasis:names:specification:ubl:schema:xsd:CreditNote-2"/>
	<phase id="BIICORET10_phase">
		<active pattern="SI-UBL-CREDIT-WARNING"/>
		<active pattern="SI-UBL-CREDIT-FATAL"/>
	</phase>
	<pattern xmlns="http://purl.oclc.org/dsdl/schematron" id="SI-UBL-CREDIT-FATAL">
		<rule context="//cac:TaxCategory" flag="fatal">
			<assert test="(parent::cac:AllowanceCharge) or (cbc:ID and cbc:Percent) or (cbc:ID = 'AE')" flag="fatal">[SI-UBL-CRE-R376]-For each tax subcategory the category ID and the applicable tax percentage MUST be provided.</assert>
		</rule>
		<rule context="//cac:AllowanceCharge" flag="fatal">
			<assert test="((//cac:TaxTotal[cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID = 'VAT']/cbc:TaxAmount) and (cac:TaxCategory/cac:TaxScheme/cbc:ID = 'VAT')) or not((//cac:TaxTotal[cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID = 'VAT']))" flag="fatal">[SI-UBL-CRE-R378]-If the VAT total amount in a Credit Note exists then an Allowances Charges amount on document level MUST have tax category for VAT.</assert>
			<assert test="number(Amount)&gt;=0" flag="fatal">[SI-UBL-CRE-R379]-An allowance or charge amount MUST NOT be negative.</assert>
		</rule>
		<rule context="/ubl:CreditNote" flag="fatal">
			<assert test="((cac:TaxTotal[cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID = 'VAT']/cbc:TaxAmount) and (cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cbc:CompanyID) or not((cac:TaxTotal[cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID = 'VAT'])))" flag="fatal">[SI-UBL-CRE-R382]-If the VAT total amount in a Credit Note exists it MUST contain the suppliers VAT number.</assert>
			<assert test="starts-with(//cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cbc:CompanyID,//cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cac:Country/cbc:IdentificationCode) and (//cac:TaxCategory/cbc:ID) = 'AE'  or not((//cac:TaxCategory/cbc:ID) = 'AE' )" flag="fatal">[SI-UBL-CRE-R383]-IF VAT = &quot;AE&quot; (reverse charge) THEN it MUST contain Supplier VAT id and Customer VAT</assert>
			<assert test="(((//cac:TaxCategory/cbc:ID) = 'AE')  and not((//cac:TaxCategory/cbc:ID) != 'AE' )) or not((//cac:TaxCategory/cbc:ID) = 'AE') or not(//cac:TaxCategory)" flag="fatal">[SI-UBL-CRE-R384]-IF VAT = &quot;AE&quot; (reverse charge) THEN VAT MAY NOT contain other VAT categories.</assert>
			<assert test="(//cbc:TaxExclusiveAmount = //cac:TaxTotal/cac:TaxSubtotal[cac:TaxCategory/cbc:ID='AE']/cbc:TaxableAmount) and (//cac:TaxCategory/cbc:ID) = 'AE'  or not((//cac:TaxCategory/cbc:ID) = 'AE' )" flag="fatal">[SI-UBL-CRE-R385]-IF VAT = &quot;AE&quot; (reverse charge) THEN The taxable amount MUST equal the invoice total without VAT amount.</assert>
			<assert test="//cac:TaxTotal/cbc:TaxAmount = 0 and (//cac:TaxCategory/cbc:ID) = 'AE'  or not((//cac:TaxCategory/cbc:ID) = 'AE' )" flag="fatal">[SI-UBL-CRE-R386]-IF VAT = &quot;AE&quot; (reverse charge) THEN VAT tax amount MUST be zero.</assert>
		</rule>
		<rule context="//cac:InvoicePeriod" flag="fatal">
			<assert test="(cbc:StartDate)" flag="fatal">[SI-UBL-CRE-R389]-If the credit note refers to a period, the period MUST have an start date.</assert>
			<assert test="(cbc:EndDate)" flag="fatal">[SI-UBL-CRE-R390]-If the credit note refers to a period, the period MUST have an end date.</assert>
		</rule>
		<rule context="cac:PartyIdentification/cbc:ID//@schemeID" flag="fatal">
			<assert test="( ( not(contains(normalize-space(.),' ')) and contains( ' GLN DUNS IBAN DK:CPR DK:CVR DK:P DK:SE DK:VANS IT:VAT IT:CF IT:FTI IT:SIA IT:SECETI NO:ORGNR NO:VAT HU:VAT SE:ORGNR FI:OVT EU:VAT EU:REID FR:SIRET AT:VAT AT:GOV AT:CID IS:KT IBAN AT:KUR ES:VAT NL:KVK NL:VAT NL:OIN ',concat(' ',normalize-space(.),' ') ) ) )" flag="fatal">[SI-UBL-CRE-R399]-Party Identifiers MUST use the PEPPOL PartyID list</assert>
		</rule>
		<rule context="//cac:Item/cac:ClassifiedTaxCategory" flag="fatal">
			<assert test="(//cac:TaxTotal[cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID = 'VAT']/cbc:TaxAmount and cbc:ID) or not((//cac:TaxTotal[cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:ID = 'VAT']))" flag="fatal">[SI-UBL-CRE-R393]-If the VAT total amount in a Credit Note exists then each Credit Note line item must have a VAT category ID.</assert>
		</rule>
		<rule context="cbc:EndpointID//@schemeID" flag="fatal">
			<assert test="( ( not(contains(normalize-space(.),' ')) and contains( ' GLN DUNS IBAN DK:CPR DK:CVR DK:P DK:SE DK:VANS IT:VAT IT:CF IT:FTI IT:SIA IT:SECETI NO:ORGNR NO:VAT HU:VAT SE:ORGNR FI:OVT EU:VAT EU:REID FR:SIRET AT:VAT AT:GOV AT:CID IS:KT IBAN AT:KUR ES:VAT NL:KVK NL:VAT NL:OIN ',concat(' ',normalize-space(.),' ') ) ) )" flag="fatal">[SI-UBL-CRE-R400]-Endpoint Identifiers MUST use the PEPPOL PartyID list.</assert>
		</rule>
	</pattern>
	<pattern xmlns="http://purl.oclc.org/dsdl/schematron" id="SI-UBL-CREDIT-WARNING">
		<rule context="/ubl:CreditNote" flag="warning">
			<assert test="contains(cbc:CustomizationID, 'urn:www.simplerinvoicing.org:si-ubl:credit-note:ver1.0.x')" flag="warning">[SI-UBL-CRE-R000]-This XML instance is NOT a SimplerInvoicing CreditNote</assert>
			<assert test="not(count(//*[not(node())]) &gt; 0)" flag="warning">[SI-UBL-CRE-R001]-A credit note SHOULD not contain empty elements.</assert>
			<assert test="not(cbc:CopyIndicator)  and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R002]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cbc:UUID)  and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R003]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cbc:IssueTime)  and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R004]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cbc:TaxPointDate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R005]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cbc:PricingCurrencyCode)  and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R006]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cbc:PaymentCurrencyCode)  and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R007]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cbc:PaymentAlternativeCurrencyCode)  and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R008]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cbc:AccountingCostCode)  and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R009]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cbc:LineCountNumeric) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R010]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:BillingReference/cac:SelfBilledInvoiceDocumentReference) or not(cac:BillingReference/cac:DebitNoteDocumentReference) or not(cac:BillingReference/cac:ReminderDocumentReference) or not(AdditionalDocumentReference) or not(BillingReferenceLine) or not(cac:BillingReference/cac:InvoiceDocumentReference/cbc:CopyIndicator) or not(cac:BillingReference/cac:InvoiceDocumentReference/cbc:UUID) or not(cac:BillingReference/cac:InvoiceDocumentReference/cbc:IssueDate) or not(cac:BillingReference/cac:InvoiceDocumentReference/cbc:DocumentTypeCode) or not(cac:BillingReference/cac:InvoiceDocumentReference/cbc:DocumentType) or not(cac:BillingReference/cac:InvoiceDocumentReference/cbc:XPath) or not(cac:BillingReference/cac:InvoiceDocumentReference/cac:Attachment) or not(cac:BillingReference/cac:CreditNoteDocumentReference/cbc:CopyIndicator) or not(cac:BillingReference/cac:CreditNoteDocumentReference/cbc:UUID) or not(cac:BillingReference/cac:CreditNoteDocumentReference/cbc:IssueDate) or not(cac:BillingReference/cac:CreditNoteDocumentReference/cbc:DocumentTypeCode) or not(cac:BillingReference/cac:CreditNoteDocumentReference/cbc:DocumentType) or not(cac:BillingReference/cac:CreditNoteDocumentReference/cbc:XPath) or not(cac:BillingReference/cac:CreditNoteDocumentReference/cac:Attachment)  and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R011]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:DespatchDocumentReference)  and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R012]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:ReceiptDocumentReference) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R013]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:OriginatorDocumentReference) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R014]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Signature) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R015]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:BuyerCustomerParty) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R016]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:SellerSupplierParty) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R017]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxRepresentativeParty) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R018]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:DeliveryTerms) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R019]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PrepaidPayment) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R020]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxExchangeRate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R021]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PricingExchangeRate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R022]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentExchangeRate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R023]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentAlternativeExchangeRate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R024]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNotePeriod/cbc:StartTime) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R025]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNotePeriod/cbc:EndTime) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R026]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNotePeriod/cbc:DurationMeasure) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R027]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNotePeriod/cbc:Description) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R028]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNotePeriod/cbc:DescriptionCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R029]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:OrderReference/cbc:SalesOrderID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R030]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:OrderReference/cbc:CopyIndicator)  and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R031]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:OrderReference/cbc:UUID)  and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R032]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:OrderReference/cbc:IssueDate)  and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R033]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:OrderReference/cbc:IssueTime)  and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R034]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:OrderReference/cbc:CustomerReference) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R035]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:OrderReference/cac:DocumentReference) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R036]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:ContractDocumentReference/cbc:CopyIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R037]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:ContractDocumentReference/cbc:UUID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R038]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:ContractDocumentReference/cbc:IssueDate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R039]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:ContractDocumentReference/cbc:DocumentTypeCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R040]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:ContractDocumentReference/cbc:XPath) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R041]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:ContractDocumentReference/cac:Attachment) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R042]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AdditionalDocumentReference/cbc:CooyIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R043]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AdditionalDocumentReference/cbc:UUID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R044]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AdditionalDocumentReference/cbc:IssueDate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R045]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AdditionalDocumentReference/cbc:DocumentTypeCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R046]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AdditionalDocumentReference/cbc:XPath) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R047]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AdditionalDocumentReference/cac:Attachment/cac:ExternalReference/cbc:DocumentHash) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R048]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AdditionalDocumentReference/cac:Attachment/cac:ExternalReference/cbc:ExpiryDate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R049]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AdditionalDocumentReference/cac:Attachment/cac:ExternalReference/cbc:ExpiryTime) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R050]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cbc:CustomerAssignedAccountID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R051]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cbc:AdditionalAccountID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R052]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cbc:DataSendingCapability) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R053]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:DespatchContact) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R054]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:AccountingContact) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R055]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:SellerContact) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R056]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cbc:MarkCareIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R057]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cbc:MarkAttentionIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R058]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cbc:WebsiteURI) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R059]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cbc:LogoReferenceID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R060]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:Language) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R061]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:AddressTypeCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R062]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:AddressFormatCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R063]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:Floor) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R064]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:Room) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R065]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:BlockName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R066]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:BuildingName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R067]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:InhouseMail) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R068]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:MarkAttention) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R069]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:MarkCare) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R070]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:PlotIdentification) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R071]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:CitySubdivisionName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R072]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:Region) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R073]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:District) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R074]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cbc:TimezoneOffset) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R075]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cac:AddressLine) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R076]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cac:Country/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R077]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PostalAddress/cac:LocationCoordinate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R078]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PhysicalLocation) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R079]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cbc:RegistrationName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R080]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cbc:TaxLevelCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R081]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cbc:ExemptionReasonCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R082]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cbc:ExemptionReason) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R083]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:RegistrationAddress) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R084]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R085]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:TaxTypeCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R086]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:CurrencyCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R087]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cac:JurisdictionRegionAddress) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R088]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:AddressTypeCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R089]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:AddressFormatCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R090]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:Postbox) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R091]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:Floor) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R092]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:Room) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R093]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:StreetName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R094]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:AdditionalStreetName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R095]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:BlockName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R096]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:BuildingName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R097]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:BuildingNumber) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R098]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:InhouseMail) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R099]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:Department) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R100]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:MarkAttention) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R101]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:MarkCare) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R102]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:PlotIdentification) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R103]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:CitySubdivisionName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R104]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:PostalZone) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R105]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:CountrySubentityCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R106]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:Region) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R107]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:District) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R108]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:TimezoneOffset) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R109]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cac:AddressLine) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R110]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cac:Country/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R111]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cac:LocationCoordinate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R112]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:PartyLegalEntity/cac:CorporateRegistrationScheme) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R113]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:Contact/cbc:ID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R114]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:Contact/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R115]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:Contact/cbc:Note) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R116]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:Contact/cac:OtherCommunication) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R117]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:Person/cbc:Title) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R118]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:Person/cbc:NameSuffix) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R119]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:Person/cbc:OrganizationDepartment) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R120]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingSupplierParty/cac:Party/cac:AgentParty) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R121]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cbc:SupplierAssignedAccountID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R122]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cbc:CustomerAssignedAccountID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R123]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cbc:AdditionalAccountID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R124]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:DeliveryContact) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R125]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:AccountingContact) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R126]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:BuyerContact) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R127]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cbc:MarkCareIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R128]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cbc:MarkAttentionIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R129]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cbc:WebsiteURI) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R130]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cbc:LogoReferenceID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R131]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:Language) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R132]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:AddressTypeCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R133]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:AddressFormatCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R134]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:Floor) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R135]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:Room) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R136]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:BlockName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R137]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:BuildingName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R138]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:InhouseMail) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R139]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:MarkAttention) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R140]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:MarkCare) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R141]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:PlotIdentification) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R142]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:CitySubdivisionName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R143]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:Region) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R144]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:District) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R145]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cbc:TimezoneOffset) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R146]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cac:AddressLine) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R147]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cac:Country/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R148]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PostalAddress/cac:LocationCoordinate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R149]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PhysicalLocation) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R150]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cbc:RegistrationName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R151]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cbc:TaxLevelCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R152]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cbc:ExemptionReasonCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R153]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cbc:ExemptionReason) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R154]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cac:RegistrationAddress) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R155]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R156]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:TaxTypeCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R157]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cbc:CurrencyCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R158]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyTaxScheme/cac:TaxScheme/cac:JurisdictionRegionAddress) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R159]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:AddressTypeCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R160]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:AddressFormatCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R161]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:Postbox) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R162]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:Floor) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R163]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:Room) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R164]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:StreetName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R165]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:AdditionalStreetName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R166]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:BlockName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R167]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:BuildingName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R168]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:BuildingNumber) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R169]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:InhouseMail) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R170]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:Department) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R171]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:MarkAttention) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R172]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:MarkCare) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R173]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:PlotIdentification) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R174]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:CitySubdivisionName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R175]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:PostalZone) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R176]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:CountrySubentityCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R177]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:Region) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R178]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:District) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R179]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cbc:TimezoneOffset) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R180]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cac:AddressLine) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R181]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cac:Country/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R182]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:RegistrationAddress/cac:LocationCoordinate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R183]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:PartyLegalEntity/cac:CorporateRegistrationScheme) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R184]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:Contact/cbc:ID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R185]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:Contact/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R186]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:Contact/cbc:Note) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R187]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:Contact/cac:OtherCommunication) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R188]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:Person/cbc:Title) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R189]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:Person/cbc:NameSuffix) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R190]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:Person/cbc:OrganizationDepartment) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R191]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AccountingCustomerParty/cac:Party/cac:AgentParty) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R192]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PayeeParty/cbc:MarkCareIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R193]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PayeeParty/cbc:MarkAttentionIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R194]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PayeeParty/cbc:WebsiteURI) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R195]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PayeeParty/cbc:LogoReferenceID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R196]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PayeeParty/cac:Language) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R197]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PayeeParty/cac:PostalAddress) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R198]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PayeeParty/cac:PhysicalLocation) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R199]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PayeeParty/cac:PartyTaxScheme) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R200]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PayeeParty/cac:PartyLegalEntity/cbc:RegistrationName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R201]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PayeeParty/cac:PartyLegalEntity/cac:RegistrationAddress) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R202]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PayeeParty/cac:PartyLegalEntity/cac:CorporateRegistrationScheme) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R203]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PayeeParty/cac:Contact) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R204]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PayeeParty/cac:Person) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R205]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PayeeParty/cac:AgentParty) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R206]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cbc:ID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R207]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cbc:Quantity) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R208]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cbc:MinimumQuantity) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R209]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cbc:MaximumQuantity) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R210]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cbc:ActualDeliveryTime) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R211]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cbc:LatestDeliveryDate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R212]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cbc:LatestDeliveryTime) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R213]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cbc:TrackingID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R214]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryAddress) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R215]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cbc:Description) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R216]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cbc:Conditions) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R217]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cbc:CountrySubentity) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R218]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cbc:CountrySubentityCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R219]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:ValidityPeriod) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R220]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:AddressTypeCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R221]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:AddressFormatCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R222]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:Floor) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R223]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:Room) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R224]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:BlockName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R225]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:BuildingName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R226]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:InhouseMail) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R227]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:Department) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R228]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:MarkAttention) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R229]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:MarkCare) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R230]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:PlotIdentification) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R231]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:CitySubdivisionName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R232]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:CountrySubentityCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R233]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:Region) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R234]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:District) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R235]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cbc:TimezoneOffset) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R236]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cac:AddressLine) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R237]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cac:Country/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R238]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Address/cac:LocationCoordinate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R239]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:RequestedDeliveryPeriod) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R240]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:PromisedDeliveryPeriod) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R241]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:EstimatedDeliveryPeriod) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R242]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:DeliveryParty) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R243]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:Delivery/cac:DeliveryLocation/cac:Despatch) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R244]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentMeans/cbc:ID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R245]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentMeans/cbc:InstructionID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R246]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentMeans/cbc:InstructionNote) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R247]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentMeans/cac:CardAccount) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R248]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentMeans/cac:PayerFinancialAccount) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R249]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentMeans/cac:CreditAccount) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R250]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentMeans/cac:PayeeFinancialAccount/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R251]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentMeans/cac:PayeeFinancialAccount/cbc:AccountTypeCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R252]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentMeans/cac:PayeeFinancialAccount/cbc:CurrencyCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R253]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentMeans/cac:PayeeFinancialAccount/cac:Country) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R254]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentMeans/cac:PayeeFinancialAccount/cac:FinancialInstitutionBranch/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R255]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentMeans/cac:PayeeFinancialAccount/cac:FinancialInstitutionBranch/cac:Address) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R256]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentMeans/cac:PayeeFinancialAccount/cac:FinancialInstitutionBranch/cac:FinancialInstitution/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R257]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentMeans/cac:PayeeFinancialAccount/cac:FinancialInstitutionBranch/cac:FinancialInstitution/cac:Address) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R258]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentTerms/cbc:ID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R259]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentTerms/cbc:PaymentMeansID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R260]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentTerms/cbc:PrepaidPaymentReferenceID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R261]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentTerms/cbc:ReferenceEventCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R262]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentTerms/cbc:SettlementDiscountPercent) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R263]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentTerms/cbc:PenaltySurchargePercent) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R264]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentTerms/cbc:Amount) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R265]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentTerms/cac:SettlementPeriod) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R266]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:PaymentTerms/cac:PenaltyPeriod) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R267]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AllowanceCharge/cbc:ID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R268]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AllowanceCharge/cbc:AllowanceChargeReasonCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R269]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AllowanceCharge/cbc:MultiplierFactorNumeric) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R270]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AllowanceCharge/cbc:PrepaidIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R271]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AllowanceCharge/cbc:SequenceNumeric) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R272]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AllowanceCharge/cbc:BaseAmount) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R273]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AllowanceCharge/cbc:AccountingCostCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R274]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AllowanceCharge/cac:TaxCategory/cbc:Name) or not(cac:AllowanceCharge/cac:TaxCategory/cbc:Percent) or not(cac:AllowanceCharge/cac:TaxCategory/cbc:BaseUnitMeasure) or not(cac:AllowanceCharge/cac:TaxCategory/cbc:PerUnitAmount) or not(cac:AllowanceCharge/cac:TaxCategory/cbc:TaxExemptionReasonCode) or not(cac:AllowanceCharge/cac:TaxCategory/cbc:TaxExemptionReason) or not(cac:AllowanceCharge/cac:TaxCategory/cbc:TierRange) or not(cac:AllowanceCharge/cac:TaxCategory/cbc:TierRatePercent) or not(cac:AllowanceCharge/cac:TaxCategory/cac:TaxScheme/cbc:Name) or not(cac:AllowanceCharge/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode) or not(cac:AllowanceCharge/cac:TaxCategory/cac:TaxScheme/cbc:CurrencyCode) or not(cac:AllowanceCharge/cac:TaxCategory/cac:TaxScheme/cac:JurisdictionRegionAddress) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R275]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AllowanceCharge/cac:TaxTotal) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R276]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:AllowanceCharge/cac:PaymentMeans) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R277]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cbc:RoundingAmount) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R278]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cbc:TaxEvidenceIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R279]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cbc:CalculationSequenceNumeric) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R280]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cbc:TransactionCurrencyTaxAmount) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R281]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cbc:Percent) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R282]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cbc:BaseUnitMeasure) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R283]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cbc:PerUnitAmount) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R284]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cbc:TierRange) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R285]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cbc:TierRatePercent) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R286]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R287]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:BaseUnitMeasure) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R288]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:PerUnitAmount) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R289]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:TierRange) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R290]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cbc:TierRatePercent) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R291]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R292]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R293]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cbc:CurrencyCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R294]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:TaxTotal/cac:TaxSubtotal/cac:TaxCategory/cac:TaxScheme/cac:JurisdictionRegionAddress) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R295]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cbc:UUID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R296]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cbc:TaxPointDate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R297]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cbc:AccountingCostCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R298]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cbc:FreeOfChargeIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R299]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:OrderLineReference/cbc:SalesOrderLineID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R300]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:DespatchLineReference) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R301]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:ReceiptLineReference) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R302]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:BillingReference) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R303]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:DocumentReference) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R304]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:PricingReference) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R305]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:OriginatorParty) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R306]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Delivery) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R307]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:PaymentTerms) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R308]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:AllowanceCharge) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R309]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:TaxTotal/cbc:RoundingAmount) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R310]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:TaxTotal/cbc:TaxEvidenceIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R311]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:TaxTotal/cac:TaxSubtotal) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R312]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cbc:PackQuantity) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R313]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cbc:PackSizeNumeric) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R314]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cbc:CatalogueIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R315]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cbc:HazardousRiskIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R316]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cbc:AdditionalInformation) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R317]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cbc:Keyword) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R318]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cbc:BrandName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R319]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cbc:ModelName) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R320]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:SellersItemIdentification/cbc:ExtendedID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R321]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:SellersItemIdentification/cbc:PhysycalAttribute) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R322]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:SellersItemIdentification/cbc:MeasurementDimension) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R323]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:SellersItemIdentification/cbc:IssuerParty) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R324]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:StandardItemIdentification/cbc:ExtendedID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R325]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:StandardItemIdentification/cbc:PhysycalAttribute) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R326]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:StandardItemIdentification/cbc:MeasurementDimension) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R327]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:StandardItemIdentification/cbc:IssuerParty) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R328]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:BuyersItemIdentification) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R329]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:CommodityClassification/cbc:NatureCargo) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R330]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:CommodityClassification/cbc:CargoTypeCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R331]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:CommodityClassification/cbc:CommodityCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R332]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:ManufacturersItemIdentification) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R333]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:CatalogueItemIdentification) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R334]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:AdditionalItemIdentification) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R335]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:CatalogueDocumentReference) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R336]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:ItemSpecificationDocumentReference) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R337]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:OriginCountry) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R338]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:TransactionConditions) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R339]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:HazardousItem) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R340]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:ManufacturerParty) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R341]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:InformationContentProviderParty) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R342]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:OriginAddress) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R343]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:ItemInstance) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R344]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:TaxCategory/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R345]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:TaxCategory/cbc:BaseUnitMeasure) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R346]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:TaxCategory/cbcPerUnitAmount) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R347]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:TaxCategory/cbc:TaxExemptionReasonCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R348]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:TaxCategory/cbc:TaxExemptionReason) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R349]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:TaxCategory/cbc:TierRange) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R350]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:TaxCategory/cbc:TierRatePercent) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R351]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:TaxCategory/cac:TaxScheme/cbc:Name) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R352]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R353]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:TaxCategory/cac:TaxScheme/cbc:CurrencyCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R354]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:TaxCategory/cac:TaxScheme/cac:JurisdictionAddress) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R355]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:TaxCategory/cac:AdditionalProperty/cac:UsabilityPeriod) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R356]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Item/cac:TaxCategory/cac:AdditionalProperty/cac:ItemPropertyGroup) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R357]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cbc:PriceChangeReason) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R358]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cbc:PriceTypeCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R359]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cbc:PriceType) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R360]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cbc:OrderableUnitFactorRate) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R361]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cac:ValidityPeriod) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R362]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cac:PriceList) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R363]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cbc:ID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R364]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cbc:AllowanceChargeReasonCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R365]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cbc:PrepaidIndicator) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R366]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cbc:SequenceNumeric) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R367]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cbc:AccountingCostCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R368]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cbc:AccountingCost) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R369]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cac:TaxCategory/cbc:Name) or not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cac:TaxCategory/cbc:Percent) or not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cac:TaxCategory/cbc:BaseUnitMeasure) or not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cac:TaxCategory/cbc:PerUnitAmount) or not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cac:TaxCategory/cbc:TaxExemptionReasonCode) or not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cac:TaxCategory/cbc:TaxExemptionReason) or not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cac:TaxCategory/cbc:TierRange) or not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cac:TaxCategory/cbc:TierRatePercent) or not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cac:TaxCategory/cac:TaxScheme/cbc:Name) or not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cac:TaxCategory/cac:TaxScheme/cbc:TaxTypeCode) or not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cac:TaxCategory/cac:TaxScheme/cbc:CurrencyCode) or not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cac:TaxCategory/cac:TaxScheme/cac:JurisdictionRegionAddress)  and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R370]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cac:TaxTotal) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R371]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:Price/cac:AllowanceCharge/cac:PaymentMeans) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R372]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:OrderLineReference/cbc:UUID) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R373]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:OrderLineReference/cbc:LineStatusCode) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R374]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
			<assert test="not(cac:CreditNoteLine/cac:OrderLineReference/cac:OrderReference) and contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0') or not(contains(cbc:CustomizationID, 'urn:www.cenbii.eu:transaction:biicoretrdm014:ver1.0'))" flag="warning">[SI-UBL-CRE-R375]-A conformant CEN BII credit note core data model SHOULD not have data elements not in the core.</assert>
		</rule>
		<rule context="//cac:AccountingCustomerParty/cac:Party" flag="warning">
			<assert test="(cac:PostalAddress/cbc:StreetName and cac:PostalAddress/cbc:CityName and cac:PostalAddress/cbc:PostalZone and cac:PostalAddress/cac:Country/cbc:IdentificationCode)" flag="warning">[SI-UBL-CRE-R377]-A customer postal address in a credit note SHOULD contain at least, street name and number, city name, zip code and country code.</assert>
		</rule>
		<rule context="//cac:AccountingSupplierParty/cac:Party" flag="warning">
			<assert test="(cac:PostalAddress/cbc:StreetName and cac:PostalAddress/cbc:CityName and cac:PostalAddress/cbc:PostalZone and cac:PostalAddress/cac:Country/cbc:IdentificationCode)" flag="warning">[SI-UBL-CRE-R388]-A supplier postal address in a credit note SHOULD contain at least, street name and number, city name, zip code and country code.</assert>
		</rule>
		<rule context="//cac:TaxSubtotal" flag="warning">
			<assert test="(number(cac:TaxCategory/cbc:Percent) = 0 and (cac:TaxCategory/cbc:TaxExemptionReason or cac:TaxCategory/cbc:TaxExemptionReasonCode)) or  (number(cac:TaxCategory/cbc:Percent) !=0)" flag="warning">[SI-UBL-CRE-R391]-If the category for VAT is exempt (E) then an exemption reason SHOULD be provided.</assert>
		</rule>
		<rule context="//cac:CreditNoteLine" flag="warning">
			<assert test="(cbc:CreditedQuantity and cbc:CreditedQuantity/@unitCode)" flag="warning">[SI-UBL-CRE-R392]-Each credit note line SHOULD contain the quantity and unit of measure</assert>
		</rule>
		<rule context="cac:FinancialInstitution/cbc:ID//@schemeID" flag="warning">
			<assert test="( ( not(contains(normalize-space(.),' ')) and contains( ' BIC ',concat(' ',normalize-space(.),' ') ) ) )" flag="warning">[SI-UBL-CRE-R394]-If FinancialAccountID is IBAN then Financial InstitutionID SHOULD be BIC code.</assert>
		</rule>
		<rule context="cac:PostalAddress/cbc:ID//@schemeID" flag="warning">
			<assert test="( ( not(contains(normalize-space(.),' ')) and contains( ' GLN ',concat(' ',normalize-space(.),' ') ) ) )" flag="warning">[SI-UBL-CRE-R395]-Postal address identifiers SHOULD be GLN.</assert>
		</rule>
		<rule context="cac:Delivery/cac:DeliveryLocation/cbc:ID//@schemeID" flag="warning">
			<assert test="( ( not(contains(normalize-space(.),' ')) and contains( ' GLN ',concat(' ',normalize-space(.),' ') ) ) )" flag="warning">[SI-UBL-CRE-R396]-Location identifiers SHOULD be GLN</assert>
		</rule>
		<rule context="cac:Item/cac:StandardItemIdentification/cbc:ID//@schemeID" flag="warning">
			<assert test="( ( not(contains(normalize-space(.),' ')) and contains( ' GTIN ',concat(' ',normalize-space(.),' ') ) ) )" flag="warning">[SI-UBL-CRE-R397]-Standard item identifiers SHOULD be GTIN.</assert>
		</rule>
		<rule context="cac:Item/cac:CommodityClassification/cbc:ItemClassificationCode//@listID" flag="warning">
			<assert test="( ( not(contains(normalize-space(.),' ')) and contains( ' UNSPSC eCLASS CPV ',concat(' ',normalize-space(.),' ') ) ) )" flag="warning">[SI-UBL-CRE-R398]-Commodity classification SHOULD be one of UNSPSC, eClass or CPV.</assert>
		</rule>
	</pattern>
</schema>
